@@ -24,7 +24,7 @@ updateQcate.MCCCA <- function(dummy.mat=dummy.mat,Ddiag.sq=Ddiag.sq#dummy.diag=d
 
   eig.res<-eigen(DZZD)
   #all(DZZD==t(DZZD))
-  if(printcheck>2) cat("    eig value of DZZD",eig.res$values[c(1:5)],"\n")
+  #if(printcheck>2) cat("    eig value of DZZD",eig.res$values[c(1:5)],"\n")
 
   #eig.res
   B.star<-eig.res$vectors[,c(1:lowdim)]#[,c(q.all:(q.all-lowdim+1))]
@@ -36,34 +36,6 @@ updateQcate.MCCCA <- function(dummy.mat=dummy.mat,Ddiag.sq=Ddiag.sq#dummy.diag=d
   #cluster CA
   #B.mat<-(sqrt(n*m))*(Ddiag.sq%*%B.star)#[,c(1:lowdim)]
 
-
-  if(printcheck>2 & !is.null(ncatevec)) {
-    ##debug
-    round(B.mat,3)
-    round(diag(Ddiag.sq),2)
-    round(Ddiag.sq%*%B.star,3)
-
-    #browser()
-    #####constraint check
-    BZZB.list<-rep(list(NA),m)
-    for(j in 1:m){
-      jjp<-ifelse(j!=1,sum(ncatevec[c(1:(j-1))]),0)
-      Zj<-dummy.mat[,c((jjp+1):(jjp+ncatevec[j]))]
-      Bj<-B.mat[c((jjp+1):(jjp+ncatevec[j])),]
-
-      if(grpbase){
-        BZZB.list[[j]]<-t(Bj)%*%t(Zj)%*%Jn%*%Zj%*%Bj
-      }else{
-        BZZB.list[[j]]<-t(Bj)%*%t(Zj)%*%Zj%*%Bj
-      }
-      #
-      #obvalvec[j]<-norm((Uk%*%Gk-Zj%*%Bj),type="F")^2
-    }
-    cat("    constraint",(1/(n.all*m))*Reduce("+",BZZB.list),"\n")
-  #both cca and grp its scale 1/Nm.
-    #browser()
-  }
-
   list(Qcate.mat=B.mat,lambda.vec=eig.res$values)#Qcate.list=W.list,
 
 }
